@@ -6,14 +6,14 @@
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "openbsd3.7"
+#define HOST_OS "openbsd3.8"
 #define HOST_OS_NAME "openbsd3"
-#define HOST_OS_VERSION "3.7"
+#define HOST_OS_VERSION "3.8"
 #define HOST_ARCH "i386"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-openbsd37.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-openbsd38.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu May 11 11:28:24 EDT 2006"
+#define CONFIG_DATE "Thu May 11 11:56:51 EST 2006"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -33,7 +33,7 @@
 #ifdef __cplusplus
 #include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "3.7"
+#define HOST_HEADER_VERSION "3.8"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_UNISTD_H 1
@@ -243,6 +243,10 @@
 #define RECVFROM_FROMLEN_TYPE int
 #define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
+#define cdfs_args_t struct iso_args
+#define mfs_args_t struct mfs_args
+#define pcfs_args_t struct msdosfs_args
+#define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
 #define HAVE_C99_VARARGS_MACROS 1
@@ -278,6 +282,13 @@
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FD_SET_FDS_BITS 1
+#define HAVE_CDFS_ARGS_T_FLAGS 1
+#define HAVE_CDFS_ARGS_T_FSPEC 1
+#define HAVE_PCFS_ARGS_T_FSPEC 1
+#define HAVE_PCFS_ARGS_T_GID 1
+#define HAVE_PCFS_ARGS_T_MASK 1
+#define HAVE_PCFS_ARGS_T_UID 1
+#define HAVE_UFS_ARGS_T_FSPEC 1
 #define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
 #define HAVE_NFS_ARGS_T_ACDIRMAX 1
@@ -305,9 +316,6 @@
 #define HAVE_FS_NFS 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
-#define HAVE_FS_NULLFS 1
-#define HAVE_FS_UNIONFS 1
-#define HAVE_FS_UMAPFS 1
 #define HAVE_AMU_FS_AUTO 1
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
@@ -321,7 +329,7 @@
 #define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS MOUNT_NFS
 #define MOUNT_TYPE_NFS3 MOUNT_NFS3
-#define MOUNT_TYPE_UFS MOUNT_UFS
+#define MOUNT_TYPE_UFS MOUNT_FFS
 #define MOUNT_TYPE_XFS MOUNT_XFS
 #define MOUNT_TYPE_CDFS MOUNT_CD9660
 #define MOUNT_TYPE_PCFS MOUNT_MSDOS
@@ -329,9 +337,6 @@
 #define MOUNT_TYPE_LOFS MOUNT_LOFS
 #define MOUNT_TYPE_LFS MOUNT_LFS
 #define MOUNT_TYPE_AFS MOUNT_AFS
-#define MOUNT_TYPE_NULLFS MOUNT_NULL
-#define MOUNT_TYPE_UNIONFS MOUNT_UNION
-#define MOUNT_TYPE_UMAPFS MOUNT_UMAP
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs3"
 #define MNTTAB_TYPE_UFS "ufs"
@@ -339,9 +344,6 @@
 #define MNTTAB_TYPE_PCFS "pcfs"
 #define MNTTAB_TYPE_MFS "mfs"
 #define MNTTAB_TYPE_LOFS "lofs"
-#define MNTTAB_TYPE_NULLFS "nullfs"
-#define MNTTAB_TYPE_UNIONFS "unionfs"
-#define MNTTAB_TYPE_UMAPFS "umapfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
 #define MNT2_GEN_OPT_FORCE 0x80000
 #define MNT2_GEN_OPT_NODEV 0x10
